@@ -284,3 +284,24 @@ class InfEngineServerEngine:
             )
             if Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).is_file():
                 Path(self._engine_dir / INF_ENGINE_LINK_DLSOURCES).unlink()
+
+    def version(self):
+        """ Get InfServer version. """
+
+        server = self._engine_dir / INF_ENGINE_BINARY_SERVER
+
+        self._logger.debug(f"Trying to check the server: {server}")
+
+        if server.is_file():
+            res = f"server --version"
+
+            completed_process = subprocess.run(res, shell=True, stdout=subprocess.PIPE)
+            process_stdout = completed_process.stdout.decode("utf-8")
+
+            if completed_process.returncode:
+                self._logger.error(f"Can't get InfEngine version: {res}")
+                raise Exception(f"Can't get InfEngine version: {res}")
+            elif process_stdout.find("Release version:") != -1:
+                return process_stdout
+
+        return None
